/*
 * This file is part of Geomajas, a component framework for building
 * rich Internet applications (RIA) with sophisticated capabilities for the
 * display, analysis and management of geographic information.
 * It is a building block that allows developers to add maps
 * and other geographic data capabilities to their web applications.
 *
 * Copyright 2008-2010 Geosparc, http://www.geosparc.com, Belgium
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package org.geomajas.gwt.client.spatial.geometry.operation;

import org.geomajas.global.Api;
import org.geomajas.gwt.client.spatial.geometry.Geometry;

/**
 * <p>
 * General interface for operations on Geometry objects. All operations should return a new Geometry instead of changing
 * the original.
 * </p>
 *
 * @author Pieter De Graef
 * @since 1.6.0
 */
// @extract-start GeometryOperation, GeometryOperation interface
@Api(allMethods = true)
public interface GeometryOperation {

	/**
	 * The main edit function. It is passed a geometry object. If other values are needed, pass them through the
	 * constructor, or via setters.
	 *
	 * @param geometry
	 *            The {@link Geometry} object to be adjusted.
	 * @return Returns the resulting geometry, leaving the original unharmed.
	 */
	Geometry execute(Geometry geometry);
}
// @extract-end
